from collections import UserList


class Path(UserList):
    """Full path manipulation in a nested object.
    
    A path is a full (starts with '/') address in a nested object.
    Items at each level are separated by '/'.
    """
    def __init__(self, items=None):
        if items is None:
            items = []
        else:
            if isinstance(items, Path):
                items = items.data
            elif isinstance(items, str):
                if items[0] != '/':
                    raise ValueError('Path class only supports absolute paths')
                items = items.strip('/').split('/')
                if items == ['']: items = []
        super().__init__(items)

    def __str__(self):
        return '/' + '/'.join(self)

    def __repr__(self):
        return f'<Path({str(self)})>'

    def __truediv__(self, other):
        return Path(self + str(other).strip('/').split('/'))

    @property
    def parent(self):
        """Get parent of path. Equivalent to `dirname`.
        
        If path is /, raise IndexError by analogy with [].pop()
        """
        if len(self) == 0:
            raise IndexError("Root '/' has no parent")
        split_path = [key for key in self]
        return Path('/' + '/'.join(split_path[:-1]))

    def startswith(self, other):
        """Check if path contains other from root /"""
        return str(self).startswith(str(other))